@@ -27,37 +27,32 @@
 #include "e-book-backend-db-cache.h"
 #include <libedata-book/e-book-backend.h>
 #include <libedata-book/e-book-backend-sexp.h>
+#include <libedataserver/e-data-server-util.h>
 
-void 
-string_to_dbt(const char *str, DBT *dbt)
+void
+string_to_dbt (const gchar *str, DBT *dbt)
 {
-	memset(dbt, 0, sizeof(dbt));
-	dbt->data = (void *)str;
-	dbt->size = strlen(str) + 1;
+	memset (dbt, 0, sizeof (dbt));
+	dbt->data = (gpointer)str;
+	dbt->size = strlen (str) + 1;
 	dbt->flags = DB_DBT_USERMEM;
 }
 
-static char *
-get_filename_from_uri (const char *uri)
+static gchar *
+get_filename_from_uri (const gchar *uri)
 {
-	char *mangled_uri, *filename;
-	int i;
+	const gchar *user_cache_dir;
+	gchar *mangled_uri, *filename;
 
-	/* mangle the URI to not contain invalid characters */
-	mangled_uri = g_strdup (uri);
-	for (i = 0; i < strlen (mangled_uri); i++) {
-		switch (mangled_uri[i]) {
-		case ':' :
-		case '/' :
-			mangled_uri[i] = '_';
-		}
-	}
+	user_cache_dir = e_get_user_cache_dir ();
 
-	/* generate the file name */
-	filename = g_build_filename (g_get_home_dir (), ".evolution/cache/addressbook",
-				     mangled_uri, "cache.db", NULL);
+	/* Mangle the URI to not contain invalid characters. */
+	mangled_uri = g_strdelimit (g_strdup (uri), ":/", '_');
+
+	filename = g_build_filename (
+		user_cache_dir, "addresbook",
+		mangled_uri, "cache.db", NULL);
 
-	/* free memory */
 	g_free (mangled_uri);
 
 	return filename;
@@ -71,11 +66,11 @@ get_filename_from_uri (const char *uri)
  * Set the filename for db cacahe file.
  **/
 
-void 
-e_book_backend_db_cache_set_filename(DB *db, const char *filename)
+void
+e_book_backend_db_cache_set_filename (DB *db, const gchar *filename)
 {
 	DBT uid_dbt, vcard_dbt;
-	int db_error;
+	gint db_error;
 
 	string_to_dbt ("filename", &uid_dbt);
 	string_to_dbt (filename, &vcard_dbt);
@@ -84,7 +79,7 @@ e_book_backend_db_cache_set_filename(DB *db, const char *filename)
 	if (db_error != 0) {
 		g_warning ("db->put failed with %d", db_error);
 	}
-	
+
 }
 
 /**
@@ -94,17 +89,17 @@ e_book_backend_db_cache_set_filename(DB *db, const char *filename)
  * Get the filename for db cacahe file.
  **/
 
-char *
-e_book_backend_db_cache_get_filename(DB *db)
+gchar *
+e_book_backend_db_cache_get_filename (DB *db)
 {
 	DBT  uid_dbt, vcard_dbt;
-	int db_error;
-	char *filename;
+	gint db_error;
+	gchar *filename;
 
 	string_to_dbt ("filename", &uid_dbt);
-	memset (&vcard_dbt, 0 , sizeof(vcard_dbt));
+	memset (&vcard_dbt, 0 , sizeof (vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
-	
+
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt, 0);
 	if (db_error != 0) {
 		g_warning ("db-<get failed with %d", db_error);
@@ -117,11 +112,11 @@ e_book_backend_db_cache_get_filename(DB *db)
 	}
 }
 
-void 
-e_book_backend_db_cache_set_time(DB *db, const char *t)
+void
+e_book_backend_db_cache_set_time (DB *db, const gchar *t)
 {
-	DBT uid_dbt, vcard_dbt ;
-	int db_error ;
+	DBT uid_dbt, vcard_dbt;
+	gint db_error;
 
 	string_to_dbt ("last_update_time", &uid_dbt);
 	string_to_dbt (t, &vcard_dbt);
@@ -132,15 +127,15 @@ e_book_backend_db_cache_set_time(DB *db, const char *t)
 	}
 }
 
-char *
+gchar *
 e_book_backend_db_cache_get_time (DB *db)
 {
 	DBT uid_dbt, vcard_dbt;
-	int db_error;
-	char *t;
+	gint db_error;
+	gchar *t;
 
 	string_to_dbt ("last_update_time", &uid_dbt);
-	memset (&vcard_dbt, 0, sizeof(vcard_dbt));
+	memset (&vcard_dbt, 0, sizeof (vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
 
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt, 0);
@@ -167,27 +162,27 @@ e_book_backend_db_cache_get_time (DB *db)
  * Return value: A cached #EContact, or %NULL if @uid is not cached.
  **/
 EContact *
-e_book_backend_db_cache_get_contact (DB *db, const char *uid)
+e_book_backend_db_cache_get_contact (DB *db, const gchar *uid)
 {
 	DBT        uid_dbt, vcard_dbt;
-	int        db_error;
-	const char *vcard_str;
+	gint        db_error;
+	const gchar *vcard_str;
 
 	g_return_val_if_fail (uid != NULL, NULL);
 
 	string_to_dbt (uid, &uid_dbt);
-	memset (&vcard_dbt, 0 , sizeof(vcard_dbt));
+	memset (&vcard_dbt, 0 , sizeof (vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
-	
+
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt,0);
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->get failed with %d", db_error);
 		return NULL;
 	}
-	
+
 	vcard_str = g_strdup (vcard_dbt.data);
 	g_free (vcard_dbt.data);
-	
+
 	return e_contact_new_from_vcard (vcard_str);
 }
 
@@ -205,9 +200,9 @@ e_book_backend_db_cache_add_contact (DB *db,
 				   EContact *contact)
 {
 	DBT        uid_dbt, vcard_dbt;
-	int        db_error;
-	char       *vcard_str;
-	const char *uid;
+	gint        db_error;
+	gchar       *vcard_str;
+	const gchar *uid;
 
 	uid = e_contact_get_const (contact, E_CONTACT_UID);
 	if (!uid) {
@@ -218,11 +213,11 @@ e_book_backend_db_cache_add_contact (DB *db,
 		email = e_contact_get (contact, E_CONTACT_EMAIL_1);
 		printf ("no uid\n");
 		printf("name:%s, email:%s\n", name, email);
-		return FALSE; 
+		return FALSE;
 	}
 	string_to_dbt (uid, &uid_dbt);
-	
-	vcard_str = e_vcard_to_string (E_VCARD(contact), EVC_FORMAT_VCARD_30);
+
+	vcard_str = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 	string_to_dbt (vcard_str, &vcard_dbt);
 
 	//db_error = db->del (db, NULL, &uid_dbt, 0);
@@ -230,11 +225,11 @@ e_book_backend_db_cache_add_contact (DB *db,
 
 	g_free (vcard_str);
 
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->put failed with %d", db_error);
 		return FALSE;
 	}
-	else 
+	else
 		return TRUE;
 }
 
@@ -249,22 +244,22 @@ e_book_backend_db_cache_add_contact (DB *db,
  **/
 gboolean
 e_book_backend_db_cache_remove_contact (DB *db,
-				    const char *uid)
-				      
+				    const gchar *uid)
+
 {
 	DBT        uid_dbt;
-	int        db_error;
+	gint        db_error;
 
 	g_return_val_if_fail (uid != NULL, FALSE);
 
 	string_to_dbt (uid, &uid_dbt);
 	db_error = db->del (db, NULL, &uid_dbt, 0);
 
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->del failed with %d", db_error);
 		return FALSE;
 	}
-	else 
+	else
 		return TRUE;
 
 }
@@ -278,22 +273,22 @@ e_book_backend_db_cache_remove_contact (DB *db,
  *
  * Return value: %TRUE if the cache contains the contact, %FALSE otherwise.
  **/
-gboolean 
-e_book_backend_db_cache_check_contact (DB *db, const char *uid)
+gboolean
+e_book_backend_db_cache_check_contact (DB *db, const gchar *uid)
 {
 	DBT        uid_dbt, vcard_dbt;
-	int        db_error;
+	gint        db_error;
 
 	g_return_val_if_fail (uid != NULL, FALSE);
 
 	string_to_dbt (uid, &uid_dbt);
-	memset (&vcard_dbt, 0 , sizeof(vcard_dbt));
+	memset (&vcard_dbt, 0 , sizeof (vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
-	
+
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt,0);
-	if (db_error != 0) 
+	if (db_error != 0)
 		return FALSE;
- 	else {
+	else {
 		free (vcard_dbt.data);
 		return TRUE;
 	}
@@ -311,11 +306,11 @@ e_book_backend_db_cache_check_contact (DB *db, const char *uid)
  * Return value: A #GList of pointers to #EContact.
  **/
 GList *
-e_book_backend_db_cache_get_contacts (DB *db, const char *query)
+e_book_backend_db_cache_get_contacts (DB *db, const gchar *query)
 {
 	DBC        *dbc;
 	DBT        uid_dbt, vcard_dbt;
-	int        db_error;
+	gint        db_error;
 	GList *list = NULL;
         EBookBackendSExp *sexp = NULL;
 	EContact *contact;
@@ -327,18 +322,18 @@ e_book_backend_db_cache_get_contacts (DB *db, const char *query)
 	}
 
 	db_error = db->cursor (db, NULL, &dbc, 0);
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->cursor failed with %d", db_error);
 		return NULL;
 	}
 
-	memset(&vcard_dbt, 0 , sizeof(vcard_dbt));
-	memset(&uid_dbt, 0, sizeof(uid_dbt));
-	db_error = dbc->c_get(dbc, &uid_dbt, &vcard_dbt, DB_FIRST);
+	memset (&vcard_dbt, 0 , sizeof (vcard_dbt));
+	memset (&uid_dbt, 0, sizeof (uid_dbt));
+	db_error = dbc->c_get (dbc, &uid_dbt, &vcard_dbt, DB_FIRST);
 
-	while(db_error == 0) {
+	while (db_error == 0) {
 		if (vcard_dbt.data && !strncmp (vcard_dbt.data, "BEGIN:VCARD", 11))
-		if (e_book_backend_sexp_match_vcard(sexp, vcard_dbt.data)) {
+		if (e_book_backend_sexp_match_vcard (sexp, vcard_dbt.data)) {
 			contact = e_contact_new_from_vcard (vcard_dbt.data);
 			list = g_list_prepend (list, contact);
 		}
@@ -346,9 +341,9 @@ e_book_backend_db_cache_get_contacts (DB *db, const char *query)
 	}
 
 	db_error = dbc->c_close (dbc);
-	if(db_error != 0)
+	if (db_error != 0)
 		g_warning ("db->c_close failed with %d", db_error);
-		
+
 	if (sexp)
 		g_object_unref (sexp);
 
@@ -367,21 +362,21 @@ e_book_backend_db_cache_get_contacts (DB *db, const char *query)
  * Return value: A #GPtrArray of pointers to contact ID strings.
  **/
 GPtrArray *
-e_book_backend_db_cache_search (DB *db, const char *query)
+e_book_backend_db_cache_search (DB *db, const gchar *query)
 {
 	GList *matching_contacts, *temp;
 	GPtrArray *ptr_array;
-	
+
 	matching_contacts = e_book_backend_db_cache_get_contacts (db, query);
 	ptr_array = g_ptr_array_new ();
-	
+
 	temp = matching_contacts;
 	for (; matching_contacts != NULL; matching_contacts = g_list_next (matching_contacts)) {
 		g_ptr_array_add (ptr_array, e_contact_get (matching_contacts->data, E_CONTACT_UID));
 		g_object_unref (matching_contacts->data);
 	}
 	g_list_free (temp);
-	
+
 	return ptr_array;
 }
 
@@ -393,18 +388,18 @@ e_book_backend_db_cache_search (DB *db, const char *query)
  *
  * Return value: %TRUE if cache exists, %FALSE if not.
  **/
-gboolean 
-e_book_backend_db_cache_exists (const char *uri)
+gboolean
+e_book_backend_db_cache_exists (const gchar *uri)
 {
-	char *file_name;
+	gchar *file_name;
 	gboolean exists = FALSE;
 	file_name = get_filename_from_uri (uri);
-	
+
 	if (file_name && g_file_test (file_name, G_FILE_TEST_EXISTS)) {
 		exists = TRUE;
 		g_free (file_name);
 	}
-	
+
 	return exists;
 }
 
@@ -412,22 +407,22 @@ e_book_backend_db_cache_exists (const char *uri)
  * e_book_backend_db_cache_set_populated:
  * @backend: an #EBookBackend
  *
- * Flags @cache as being populated - that is, it is up-to-date on the 
+ * Flags @cache as being populated - that is, it is up-to-date on the
  * contents of the book it's caching.
  **/
 void
 e_book_backend_db_cache_set_populated (DB *db)
 {
 	DBT        uid_dbt, vcard_dbt;
-	int        db_error;
+	gint        db_error;
 
 	string_to_dbt ("populated", &uid_dbt);
 	string_to_dbt ("TRUE", &vcard_dbt);
 	db_error = db->put (db, NULL, &uid_dbt, &vcard_dbt, 0);
-	if (db_error != 0) { 
+	if (db_error != 0) {
 		g_warning ("db->put failed with %d", db_error);
 	}
-	
+
 }
 
 /**
@@ -442,18 +437,18 @@ gboolean
 e_book_backend_db_cache_is_populated (DB *db)
 {
 	DBT        uid_dbt, vcard_dbt;
-	int        db_error;
-	
+	gint        db_error;
+
 	string_to_dbt ("populated", &uid_dbt);
-	memset(&vcard_dbt, 0, sizeof(vcard_dbt));
+	memset (&vcard_dbt, 0, sizeof (vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
 
 	db_error = db->get (db, NULL, &uid_dbt, &vcard_dbt, 0);
-	if (db_error != 0){
+	if (db_error != 0) {
 		return FALSE;
 	}
 	else {
-		free(vcard_dbt.data);
+		free (vcard_dbt.data);
 		return TRUE;
 	}
 }
