@@ -44,18 +44,18 @@
 G_DEFINE_TYPE (CamelExchangeSummary, camel_exchange_summary, CAMEL_TYPE_FOLDER_SUMMARY)
 
 static gboolean
-exchange_summary_check_for_trash (CamelFolder *folder)
+exchange_summary_check_for_trash (CamelFolder *folder,
+                                  GCancellable *cancellable)
 {
 	CamelStore *parent_store;
 	CamelFolder *trash;
-	CamelException lex;
-
-	camel_exception_init (&lex);
 
 	parent_store = camel_folder_get_parent_store (folder);
-	trash = camel_store_get_trash (parent_store, &lex);
 
-	if (camel_exception_is_set (&lex) || !trash)
+	trash = camel_store_get_trash_folder_sync (
+		parent_store, cancellable, NULL);
+
+	if (trash == NULL)
 		return FALSE;
 
 	return folder == trash;
@@ -63,27 +63,28 @@ exchange_summary_check_for_trash (CamelFolder *folder)
 
 static gboolean
 exchange_summary_expunge_mail (CamelFolder *folder,
-                               CamelMessageInfo *info)
+                               CamelMessageInfo *info,
+                               GCancellable *cancellable,
+                               GError **error)
 {
 	GPtrArray *uids = g_ptr_array_new ();
 	CamelStore *parent_store;
 	gchar *uid = g_strdup (info->uid);
-	CamelException lex;
 	const gchar *full_name;
-
-	camel_exception_init (&lex);
+	gboolean success;
 
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
 	g_ptr_array_add (uids, uid);
 
-	camel_exchange_utils_expunge_uids (
-		CAMEL_SERVICE (parent_store), full_name, uids, &lex);
+	success = camel_exchange_utils_expunge_uids (
+		CAMEL_SERVICE (parent_store),
+		full_name, uids, cancellable, error);
 
 	g_ptr_array_free (uids, TRUE);
 
-	return camel_exception_is_set (&lex);
+	return success;
 }
 
 static gint
@@ -242,7 +243,7 @@ exchange_summary_message_info_free (CamelFolderSummary *summary,
 
 static CamelFIRecord *
 exchange_summary_summary_header_to_db (CamelFolderSummary *s,
-                                       CamelException *ex)
+                                       GError **error)
 {
 	CamelExchangeSummary *exchange = (CamelExchangeSummary *) s;
 	CamelFolderSummaryClass *folder_summary_class;
@@ -251,7 +252,7 @@ exchange_summary_summary_header_to_db (CamelFolderSummary *s,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	fir = folder_summary_class->summary_header_to_db (s, ex);
+	fir = folder_summary_class->summary_header_to_db (s, error);
 	if (!fir)
 		return NULL;
 	fir->bdata = g_strdup_printf ("%u %u %u", exchange->version, exchange->readonly, exchange->high_article_num);
@@ -354,29 +355,29 @@ exchange_summary_info_set_flags (CamelMessageInfo *info,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	if (offline_store->state != CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
+	if (!camel_offline_store_get_online (offline_store)) {
 		if (folder && info->uid) {
 			if ((flags & set & CAMEL_MESSAGE_DELETED) &&
-			    exchange_summary_check_for_trash (folder)) {
-				return exchange_summary_expunge_mail (folder, info);
+			    exchange_summary_check_for_trash (folder, NULL)) {
+				return exchange_summary_expunge_mail (folder, info, NULL, NULL);
 			} else {
 				camel_exchange_utils_set_message_flags (
 					CAMEL_SERVICE (parent_store),
 					full_name, info->uid, set, flags, NULL);
-				return folder_summary_class->info_set_flags(info, flags, set);
+				return folder_summary_class->info_set_flags (info, flags, set);
 			}
 		}
 	}
 	else {
 		if (folder && info->uid) {
 			if ((flags & set & CAMEL_MESSAGE_DELETED) &&
-			    exchange_summary_check_for_trash (folder)) {
+			    exchange_summary_check_for_trash (folder, NULL)) {
 				/* FIXME: should add a separate journal entry for this case. */ ;
 			} else {
 				CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) folder;
 				CamelExchangeJournal *journal = (CamelExchangeJournal *) exchange_folder->journal;
 				camel_exchange_journal_delete (journal, info->uid, flags, set, NULL);
-				return folder_summary_class->info_set_flags(info, flags, set);
+				return folder_summary_class->info_set_flags (info, flags, set);
 			}
 		}
 	}
@@ -397,7 +398,7 @@ exchange_summary_info_set_user_tag (CamelMessageInfo *info,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	res = folder_summary_class->info_set_user_tag(info, name, value);
+	res = folder_summary_class->info_set_user_tag (info, name, value);
 	if (res && info->summary->folder && info->uid) {
 		CamelFolder *folder = info->summary->folder;
 		CamelStore *parent_store;
@@ -453,22 +454,21 @@ CamelFolderSummary *
 camel_exchange_summary_new (struct _CamelFolder *folder, const gchar *filename)
 {
 	CamelFolderSummary *summary;
-	CamelException lex;
+	GError *local_error = NULL;
 
-	camel_exception_init (&lex);
 	summary = g_object_new (CAMEL_TYPE_EXCHANGE_SUMMARY, NULL);
 	summary->folder = folder;
 	camel_folder_summary_set_filename (summary, filename);
-	if (camel_folder_summary_load_from_db (summary, &lex) == -1) {
+	if (camel_folder_summary_load_from_db (summary, &local_error) == -1) {
 		g_warning (
 			"Unable to load Exchage summary for folder %s: %s\n",
 			camel_folder_get_full_name (folder),
-			camel_exception_get_description(&lex));
+			local_error->message);
 		camel_folder_summary_clear_db (summary);
 		camel_folder_summary_touch (summary);
+		g_error_free (local_error);
 	}
 
-	camel_exception_clear (&lex);
 	return summary;
 }
 
@@ -572,20 +572,20 @@ camel_exchange_summary_add_offline (CamelFolderSummary *summary,
 	mi = (CamelMessageInfoBase *)camel_folder_summary_info_new_from_message (summary, message, NULL);
 
 	/* Copy flags 'n' tags */
-	mi->flags = camel_message_info_flags(info);
+	mi->flags = camel_message_info_flags (info);
 
-	flag = camel_message_info_user_flags(info);
+	flag = camel_message_info_user_flags (info);
 	while (flag) {
-		camel_message_info_set_user_flag((CamelMessageInfo *)mi, flag->name, TRUE);
+		camel_message_info_set_user_flag ((CamelMessageInfo *)mi, flag->name, TRUE);
 		flag = flag->next;
 	}
-	tag = camel_message_info_user_tags(info);
+	tag = camel_message_info_user_tags (info);
 	while (tag) {
-		camel_message_info_set_user_tag((CamelMessageInfo *)mi, tag->name, tag->value);
+		camel_message_info_set_user_tag ((CamelMessageInfo *)mi, tag->name, tag->value);
 		tag = tag->next;
 	}
 
-	mi->size = camel_message_info_size(info);
+	mi->size = camel_message_info_size (info);
 	mi->uid = camel_pstring_strdup (uid);
 	camel_folder_summary_add (summary, (CamelMessageInfo *)mi);
 }
@@ -607,7 +607,7 @@ camel_exchange_summary_add_offline_uncached (CamelFolderSummary *summary,
 	CamelMessageInfo *mi;
 
 	/* Create summary entry */
-	mi = camel_message_info_clone(info);
+	mi = camel_message_info_clone (info);
 
 	/* Set uid and add to summary */
 	mi->uid = camel_pstring_strdup (uid);
